import React, { useState, useRef, useEffect } from 'react';
import { Button, DatePicker, Input, Select, Space, Table } from 'antd';
import styles from './index.less';
import ContractModal, { Type } from './component/Modal';
import { PageContainer } from '@ant-design/pro-components';
import { useRequest } from '@umijs/max';
import { connect } from 'umi';
import {
  queryApproval,
  queryContract,
  queryGetContractList,
} from '../../services/contract';

const ConteactManager = (props) => {
  const { dispatch } = props;
  const [searchData, setSearchData] = useState({
    effect_on: '',
    project_name: '',
    status: '',
    page_size: 10,
    current: 0,
    name: '',
  });
  const [visible, setVisible] = useState(false);
  const typeRef = useRef();
  const parentIdRef = useRef(0);

  const columns = [
    {
      title: '合同编号',
      dataIndex: 'code',
      key: 'code',
    },
    {
      title: '合同生效时间',
      dataIndex: 'effect_on',
      key: 'effect_on',
    },
    {
      title: '合同名称',
      dataIndex: 'name',
      key: 'name',
    },
    {
      title: '甲方',
      dataIndex: 'party_a',
      key: 'party_a',
    },
    {
      title: '丙方',
      dataIndex: 'party_c',
      key: 'party_c',
    },
    {
      title: '所属部门/子公司',
      dataIndex: 'company_name',
      key: 'company_name',
    },
    {
      title: '项目名称',
      dataIndex: 'project_name',
      key: 'project_name',
    },
    {
      title: '合同总价（万元）',
      dataIndex: 'amount',
      key: 'amount',
    },
    {
      title: '经办人',
      dataIndex: 'deal_by',
      key: 'deal_by',
    },
    {
      title: '状态',
      dataIndex: 'status',
      key: 'status',
      render: (status) => {
        let str = '';
        switch (status) {
          case 1:
            str = '待审核';
            break;
          case 2:
            str = '审核拒绝';
            break;
          case 3:
            str = '已存档';
            break;
          case 4:
            str = '作废待审核';
            break;
          case 5:
            str = '作废拒绝';
            break;
          case 6:
            str = '已作废';
            break;
        }
        return <div>{str}</div>;
      },
    },
    {
      title: '操作',
      dataIndex: 'address',
      align: 'center',
      render: (record) => {
        return (
          <Space>
            <a
              onClick={() => {
                typeRef.current = Type.detail;
                parentIdRef.current = 0;
                setVisible(true);
              }}
            >
              详情
            </a>
            <a onClick={handlePreView}>预览</a>
            <a onClick={handleUpload}>下载</a>
            <a
              onClick={() => {
                typeRef.current = Type.add;
                parentIdRef.current = record.id;
                setVisible(true);
              }}
            >
              增补
            </a>
            <a
              onClick={() => {
                typeRef.current = Type.cancel;
                setVisible(true);
              }}
            >
              作废
            </a>
          </Space>
        );
      },
    },
  ];
  const dataSource = [
    {
      key: 1,
      name: 'John Brown sr.',
      age: 60,
      address: 'New York ',
      children: [
        {
          key: 11,
          name: 'John Brown',
          age: 42,
          address: 'New York No. 2 Lake Park',
        },
        {
          key: 12,
          name: 'John Brown jr.',
          age: 30,
          address: 'New York No. 3 Lake Park',
          children: [
            {
              key: 121,
              name: 'Jimmy Brown',
              age: 16,
              address: 'New York No. 3 Lake Park',
            },
          ],
        },
        {
          key: 13,
          name: 'Jim Green sr.',
          age: 72,
          address: 'London No. 1 Lake Park',
          children: [
            {
              key: 131,
              name: 'Jim Green',
              age: 42,
              address: 'London No. 2 Lake Park',
              children: [
                {
                  key: 1311,
                  name: 'Jim Green jr.',
                  age: 25,
                  address: 'London No. 3 Lake Park',
                },
                {
                  key: 1312,
                  name: 'Jimmy Green sr.',
                  age: 18,
                  address: 'London No. 4 Lake Park',
                },
              ],
            },
          ],
        },
      ],
    },
    {
      key: 2,
      name: 'Joe Black',
      age: 32,
      address: 'Sydney No',
    },
  ];

  useEffect(() => {
    dispatch({
      type: 'user/fetch',
    });
  }, []);

  //请求列表
  const { data, run } = useRequest((data) => queryGetContractList(data), {
    defaultParams: [searchData],
  });
  console.log('==============', data);
  //编辑新增接口
  const { data: addData, run: editRun } = useRequest(
    (data) => queryContract(data),
    {
      manual: true,
    },
  );

  //请求项目列表
  const { data: projectData } = useRequest(queryApproval, {
    defaultParams: [{ pageSize: 99999 }],
  });

  const handlePreView = () => {
    // originFileObj 是读取的文件对象，如上传组件读取到的
    // const fileURL = URL.createObjectURL(originFileObj);
    // window.open(fileURL);
  };

  const handleUpload = () => {};
  const handleSearch = () => {};
  const handleExport = () => {
    typeRef.current = Type.audit;
    setVisible(true);
  };

  const handleOk = (data) => {
    console.log('-----------', data);
    run(data);
  };
  return (
    <PageContainer>
      <div className={styles.searchContent}>
        <div className={styles.itemFlex}>
          <div>合同生效日期：</div>
          <DatePicker
            onChange={(e) => {
              setSearchData({ effect_on: e });
            }}
          />
        </div>
        <div className={styles.itemFlex}>
          <div>项目名称：</div>
          <Select
            style={{ width: 200 }}
            placeholder="请选择"
            onChange={(e) => {
              setSearchData({ project_name: e });
            }}
            options={projectData?.list?.map((item) => {
              return {
                value: item.project_full_code,
                label: item.project_name,
              };
            })}
          />
        </div>
        <div className={styles.itemFlex}>
          <div>状态：</div>
          <Select
            style={{ width: 150 }}
            placeholder="请选择"
            onChange={(e) => {
              setSearchData({ status: e });
            }}
            options={[
              { value: 0, label: '已归档' },
              { value: 1, label: '归档审核中' },
              { value: 2, label: '作废审核中' },
              { value: 3, label: '已作废' },
              { value: 4, label: '归档拒绝' },
              { value: 5, label: '作废拒绝' },
            ]}
          />
        </div>
        <Input
          className={styles.inputSty}
          placeholder="请输入合同名称/编号"
          onChange={(e) => {
            setSearchData({ project_name: e.target.value });
          }}
        />
        <Button
          type="primary"
          className={styles.searchBtnSty}
          onClick={handleSearch}
        >
          查询
        </Button>
        <Button
          type="primary"
          onClick={() => {
            typeRef.current = Type.add;
            setVisible(true);
          }}
        >
          新增
        </Button>
        <Button
          type="primary"
          className={styles.exportBtnSty}
          onClick={handleExport}
        >
          导出
        </Button>
      </div>
      <Table
        columns={columns}
        dataSource={data?.list}
        // pagination={data?.pagination}
      />
      <ContractModal
        type={typeRef.current}
        parent_id={parentIdRef.current}
        projectList={projectData?.list}
        visible={visible}
        handleOk={handleOk}
        handleCancel={() => setVisible(false)}
      />
    </PageContainer>
  );
};
export default connect(({ user, loading }) => ({
  userList: user.list,
}))(ConteactManager);
